/****************************************************************************/
// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
// Copyright (C) 2001-2019 German Aerospace Center (DLR) and others.
// This program and the accompanying materials
// are made available under the terms of the Eclipse Public License v2.0
// which accompanies this distribution, and is available at
// http://www.eclipse.org/legal/epl-v20.html
// SPDX-License-Identifier: EPL-2.0
/****************************************************************************/
/// @file    GUIGlobals.cpp
/// @author  Daniel Krajzewicz
/// @author  Michael Behrisch
/// @date    2004
///
// }
/****************************************************************************/


// ===========================================================================
// included modules
// ===========================================================================
#include <config.h>

#include "GUIGlobals.h"


// ===========================================================================
// static member variables definitions
// ===========================================================================
bool GUIGlobals::gRunAfterLoad = false;


bool GUIGlobals::gQuitOnEnd = false;


bool GUIGlobals::gDemoAutoReload = false;


double GUIGlobals::gTrackerInterval = 1.0;

/****************************************************************************/
